
#                                scala.util.Try                                #

```
sealed abstract class Try[+T] extends AnyRef
```

The `Try` type represents a computation that may either result in an exception,
or return a successfully computed value. It's similar to, but semantically
different from the scala.util.Either type.

Instances of `Try[T]` , are either an instance of scala.util.Success [T] or
scala.util.Failure [T].

For example, `Try` can be used to perform division on a user-defined input,
without the need to do explicit exception-handling in all of the places that an
exception might occur.

Example:

```scala
import scala.util.{Try, Success, Failure}

def divide: Try[Int] = {
  val dividend = Try(Console.readLine("Enter an Int that you'd like to divide:\n").toInt)
  val divisor = Try(Console.readLine("Enter an Int that you'd like to divide by:\n").toInt)
  val problem = dividend.flatMap(x => divisor.map(y => x/y))
  problem match {
    case Success(v) =>
      println("Result of " + dividend.get + "/"+ divisor.get +" is: " + v)
      Success(v)
    case Failure(e) =>
      println("You must've divided by zero or entered something that's not an Int. Try again!")
      println("Info from the exception: " + e.getMessage)
      divide
  }
}
```

An important property of `Try` shown in the above example is its ability to _
pipeline_ , or chain, operations, catching exceptions along the way. The
 `flatMap` and `map` combinators in the above example each essentially pass off
either their successfully completed value, wrapped in the `Success` type for it
to be further operated upon by the next combinator in the chain, or the
exception wrapped in the `Failure` type usually to be simply passed on down the
chain. Combinators such as `rescue` and `recover` are designed to provide some
type of default behavior in the case of failure.

 _Note_ : only non-fatal exceptions are caught by the combinators on `Try` (see
scala.util.control.NonFatal). Serious system errors, on the other hand, will be
thrown.

 _Note:_ : all Try combinators will catch exceptions and return failure unless
otherwise specified in the documentation.

 `Try` comes to the Scala standard library after years of use as an integral
part of Twitter's stack.

* Source
  * [Try.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/util/Try.scala#L1)
* Since
  * 2.10


--------------------------------------------------------------------------------
                                  Type Members
--------------------------------------------------------------------------------


### `class WithFilter extends AnyRef`                                        ###

We need a whole WithFilter class to honor the "doesn't create a new collection"
contract even though it seems unlikely to matter much in a collection with max
size 1.

* Source
  * [Try.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/util/Try.scala#L1)


--------------------------------------------------------------------------------
                   Abstract Value Members From scala.util.Try
--------------------------------------------------------------------------------


### `abstract def failed: Try[Throwable]`                                    ###

Completes this `Try` with an exception wrapped in a `Success` . The exception is
either the exception that the `Try` failed with (if a `Failure` ) or an
 `UnsupportedOperationException` .

(defined at scala.util.Try)


### `abstract def filter(p: (T) ⇒ Boolean): Try[T]`                          ###

Converts this to a `Failure` if the predicate is not satisfied.

(defined at scala.util.Try)


### `abstract def flatMap[U](f: (T) ⇒ Try[U]): Try[U]`                       ###

Returns the given function applied to the value from this `Success` or returns
this if this is a `Failure` .

(defined at scala.util.Try)


### `abstract def flatten[U](implicit ev: <:<[T, Try[U]]): Try[U]`           ###

Transforms a nested `Try` , ie, a `Try` of type `Try[Try[T]]` , into an
un-nested `Try` , ie, a `Try` of type `Try[T]` .

(defined at scala.util.Try)


### `abstract def foreach[U](f: (T) ⇒ U): Unit`                              ###

Applies the given function `f` if this is a `Success` , otherwise returns
 `Unit` if this is a `Failure` .

 _Note:_ If `f` throws, then this method may throw an exception.

(defined at scala.util.Try)


### `abstract def get: T`                                                    ###

Returns the value from this `Success` or throws the exception if this is a
 `Failure` .

(defined at scala.util.Try)


### `abstract def isFailure: Boolean`                                        ###

Returns `true` if the `Try` is a `Failure` , `false` otherwise.

(defined at scala.util.Try)


### `abstract def isSuccess: Boolean`                                        ###

Returns `true` if the `Try` is a `Success` , `false` otherwise.

(defined at scala.util.Try)


### `abstract def map[U](f: (T) ⇒ U): Try[U]`                                ###

Maps the given function to the value from this `Success` or returns this if this
is a `Failure` .

(defined at scala.util.Try)


### `abstract def recoverWith[U >: T](f: PartialFunction[Throwable, Try[U]]): Try[U]` ###

Applies the given function `f` if this is a `Failure` , otherwise returns this
if this is a `Success` . This is like `flatMap` for the exception.

(defined at scala.util.Try)


### `abstract def recover[U >: T](f: PartialFunction[Throwable, U]): Try[U]` ###

Applies the given function `f` if this is a `Failure` , otherwise returns this
if this is a `Success` . This is like map for the exception.

(defined at scala.util.Try)


--------------------------------------------------------------------------------
                   Concrete Value Members From scala.util.Try
--------------------------------------------------------------------------------


### `def getOrElse[U >: T](default: ⇒ U): U`                                 ###

Returns the value from this `Success` or the given `default` argument if this is
a `Failure` .

 _Note:_ : This will throw an exception if it is not a success and default
throws an exception.

(defined at scala.util.Try)


### `def orElse[U >: T](default: ⇒ Try[U]): Try[U]`                          ###

Returns this `Try` if it's a `Success` or the given `default` argument if this
is a `Failure` .

(defined at scala.util.Try)


### `def toOption: Option[T]`                                                ###

Returns `None` if this is a `Failure` or a `Some` containing the value if this
is a `Success` .

(defined at scala.util.Try)


### `def transform[U](s: (T) ⇒ Try[U], f: (Throwable) ⇒ Try[U]): Try[U]`     ###

Completes this `Try` by applying the function `f` to this if this is of type
 `Failure` , or conversely, by applying `s` if this is a `Success` .

(defined at scala.util.Try)


### `final def withFilter(p: (T) ⇒ Boolean): WithFilter`                     ###

Creates a non-strict filter, which eventually converts this to a `Failure` if
the predicate is not satisfied.

Note: unlike filter, withFilter does not create a new Try. Instead, it restricts
the domain of subsequent `map` , `flatMap` , `foreach` , and `withFilter`
operations.

As Try is a one-element collection, this may be a bit overkill, but it's
consistent with withFilter on Option and the other collections.

* p
  * the predicate used to test elements.
* returns
  * an object of class `WithFilter` , which supports `map` , `flatMap` ,
     `foreach` , and `withFilter` operations. All these operations apply to
    those elements of this Try which satisfy the predicate `p` .

* Annotations
  * @ inline ()
(defined at scala.util.Try)
